@@ -48,7 +48,8 @@ DEFAULTS = {
     'AUTO_GENERATE_TASKS_FOR_DJANGO_COMMANDS': {},
     'CELERY_HEALTH_CHECK_DEFAULT_QUEUE': getattr(django_settings, 'CELERY_DEFAULT_QUEUE', 'default'),
     'LOG_DB_NAME': None,
-    'PURGE_LOG_BATCH': 30000,
+    'PURGE_LOG_BACKUP_BATCH': 20000,
+    'PURGE_LOG_DELETE_BATCH': 1000,
 }
 
 
